summaryrefslogtreecommitdiffstats
path: root/kio/kssl/ksslsettings.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kio/kssl/ksslsettings.cc
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kio/kssl/ksslsettings.cc')
-rw-r--r--kio/kssl/ksslsettings.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/kio/kssl/ksslsettings.cc b/kio/kssl/ksslsettings.cc
index 5a77b12bf..55f34dd18 100644
--- a/kio/kssl/ksslsettings.cc
+++ b/kio/kssl/ksslsettings.cc
@@ -169,7 +169,7 @@ TQString KSSLSettings::getCipherList() {
int bits = d->kossl->SSL_CIPHER_get_bits(sc, NULL);
if (m_cfg->readBoolEntry(tcipher, bits >= 56)) {
CipherNode *xx = new CipherNode(sc->name,bits);
- if (!cipherList.contains(xx))
+ if (!cipherList.tqcontains(xx))
cipherList.prepend(xx);
else
delete xx;
@@ -183,7 +183,7 @@ TQString KSSLSettings::getCipherList() {
for (unsigned int i = 0; i < cipherList.count(); i++) {
CipherNode *j = 0L;
while ((j = cipherList.at(i)) != 0L) {
- if (j->name.contains("ADH-") || j->name.contains("NULL-") || j->name.contains("DES-CBC3-SHA") || j->name.contains("FZA")) {
+ if (j->name.tqcontains("ADH-") || j->name.tqcontains("NULL-") || j->name.tqcontains("DES-CBC3-SHA") || j->name.tqcontains("FZA")) {
cipherList.remove(j);
} else {
break;
@@ -298,7 +298,7 @@ void KSSLSettings::save() {
for (unsigned int i = 0; i < v2ciphers.count(); i++) {
TQString ciphername;
ciphername.sprintf("cipher_%s", v2ciphers[i].ascii());
- if (v2selectedciphers.contains(v2ciphers[i])) {
+ if (v2selectedciphers.tqcontains(v2ciphers[i])) {
m_cfg->writeEntry(ciphername, true);
} else m_cfg->writeEntry(ciphername, false);
}
@@ -307,7 +307,7 @@ void KSSLSettings::save() {
for (unsigned int i = 0; i < v3ciphers.count(); i++) {
TQString ciphername;
ciphername.sprintf("cipher_%s", v3ciphers[i].ascii());
- if (v3selectedciphers.contains(v3ciphers[i])) {
+ if (v3selectedciphers.tqcontains(v3ciphers[i])) {
m_cfg->writeEntry(ciphername, true);
} else m_cfg->writeEntry(ciphername, false);
}
@@ -315,7 +315,7 @@ void KSSLSettings::save() {
m_cfg->sync();
// insure proper permissions -- contains sensitive data
TQString cfgName(KGlobal::dirs()->findResource("config", "cryptodefaults"));
if (!cfgName.isEmpty())
::chmod(TQFile::encodeName(cfgName), 0600);
@@ -315,7 +315,7 @@ void KSSLSettings::save() {
m_cfg->sync();
- // insure proper permissions -- contains sensitive data
+ // insure proper permissions -- tqcontains sensitive data
TQString cfgName(KGlobal::dirs()->findResource("config", "cryptodefaults"));
if (!cfgName.isEmpty())